@@ -25,8 +25,8 @@ extern "C" {
     int widget##_move_up(widget *);                                                                \
     int widget##_move_down(widget *);                                                              \
     void widget##_show_cursor(widget *, int boolean);                                              \
-    void widget##_set_highlight_data(widget *self, void *sbuf, unsigned int *color, int *font,  \
-                                        int *fontsz, int sz);                                      \
+    void widget##_set_highlight_data(widget *self, void *sbuf, unsigned int *color, int *font,     \
+                                     int *fontsz, int sz);                                         \
     void widget##_set_cursor_style(widget *, int style);                                           \
     void widget##_set_cursor_color(widget *, unsigned int color);                                  \
     void widget##_set_scrollbar_size(widget *, int newSize);                                       \
@@ -144,6 +144,18 @@ void Fl_Text_Buffer_remove_modify_callback(Fl_Text_Buffer *self, Fl_Text_Modify_
 
 void Fl_Text_Buffer_call_modify_callbacks(Fl_Text_Buffer *self);
 
+int Fl_Text_Buffer_search_forward(const Fl_Text_Buffer *self, int start_pos,
+                                  const char *search_string, int *found_pos, int match_case);
+
+int Fl_Text_Buffer_search_backward(const Fl_Text_Buffer *self, int start_pos,
+                                   const char *search_string, int *found_pos, int match_case);
+
+int Fl_Text_Buffer_findchar_forward(const Fl_Text_Buffer *self, int start_pos,
+                                  unsigned int search_char, int *found_pos);
+
+int Fl_Text_Buffer_findchar_backward(const Fl_Text_Buffer *self, int start_pos,
+                                   unsigned int search_char, int *found_pos);
+
 WIDGET_DECLARE(Fl_Text_Display)
 
 void Fl_Text_Display_init(Fl_Text_Display *);
